@@ -24,7 +24,7 @@ my %CONFIG = (
 
 $globals->current_user_path_level( 1 );
 $globals->set_prefs( \%CONFIG );
-$globals->call_component( 'CGI::WPM::SegTextDoc' );
+$globals->call_component( 'DemoSegTextDoc' );
 
 $io->send_user_output( $globals );
 
