@@ -17,7 +17,7 @@ require 5.004;
 
 use strict;
 use vars qw($VERSION);
-$VERSION = '0.45';
+$VERSION = '0.46';
 
 ######################################################################
 
@@ -33,7 +33,7 @@ $VERSION = '0.45';
 
 =head2 Nonstandard Modules
 
-	CGI::Portable 0.45
+	CGI::Portable 0.46
 
 =head1 SYNOPSIS
 
@@ -149,11 +149,9 @@ sub fetch_user_input {
 		$query = $ENV{'QUERY_STRING'};
 		$query ||= $ENV{'REDIRECT_QUERY_STRING'};
 		
-		if( $ENV{'CONTENT_LENGTH'} <= 100_000 ) {
+		if( $ENV{'CONTENT_LENGTH'} > 0 ) {
 			read( STDIN, $post, $ENV{'CONTENT_LENGTH'} );
 			chomp( $post );
-		} else {  # post too large, error condition, post not taken
-			$oversize = 100_000;
 		}
 
 		$cookies = $ENV{'HTTP_COOKIE'} || $ENV{'COOKIE'};
