@@ -8,14 +8,16 @@
 
 BEGIN { $| = 1; print "1..1\n"; }
 END {print "not ok 1\n" unless $loaded;}
-use CGI::Portable::Errors 0.45;
-use CGI::Portable::Files 0.45;
-use CGI::Portable::Request 0.45;
-use CGI::Portable::Response 0.45;
-use CGI::Portable 0.45;
-use CGI::Portable::AdapterCGI 0.45;
-use CGI::Portable::AdapterSocket 0.45;
-use CGI::Portable::AppStatic 0.45;
+use CGI::Portable::Errors 0.46;
+use CGI::Portable::Files 0.46;
+use CGI::Portable::Request 0.46;
+use CGI::Portable::Response 0.46;
+use CGI::Portable 0.46;
+use CGI::Portable::AdapterCGI 0.46;
+use CGI::Portable::AdapterSocket 0.46;
+use CGI::Portable::AppStatic 0.46;
+use CGI::Portable::AppMultiScreen 0.46;
+use CGI::Portable::AppSplitScreen 0.46;
 $loaded = 1;
 print "ok 1\n";
 use strict;
